@@ -35,7 +35,7 @@ class Intercom:
         self._wait_forever = Event()
         self._control = Control(config)
         self._devices = Devices(self._config, self._shutdown)
-        self._mumble = Mumble(self._control, config)
+        self._mumble = Mumble(self._control, config, self._shutdown)
         self._sound = Sound(self._devices, self._mumble, self._control, config)
         self._server = Server(self._devices, self._shutdown)
 
@@ -58,7 +58,7 @@ class Intercom:
 
     async def run(self):
         try:
-            logger.info("Starting up rpi_intercom v" + pkg_resources.get_distribution("rpi_intercom").version)
+            #logger.info("Starting up rpi_intercom v" + pkg_resources.get_distribution("rpi_intercom").version)
             self.start()
             signal.signal(signal.SIGQUIT, self._do_shutdown)
             signal.signal(signal.SIGTERM, self._do_shutdown)
